butterbee
Values
pub fn init() -> Nil
Initialize butterbee,
Call this in the main function of your test, before calling gleeunit.main.
Then call driver.new in your test
to start using butterbee.
pub fn init() -> Nil
Initialize butterbee,
Call this in the main function of your test, before calling gleeunit.main.
Then call driver.new in your test
to start using butterbee.