butterbee/by
The by module contains functions to specify the type of locator to use to query for web elements.
For resources on how to use xpath and css locators, see Xpath cheatsheet.
Values
pub fn css(value: String) -> locator.Locator
pub fn inner_text(
value: String,
match_type: locator.MatchType,
) -> locator.Locator
pub fn xpath(value: String) -> locator.Locator