butterbee/commands/script

Script commands

The script commands module contains commands found in the script section of the webdriver bidi protocol. Butterbee uses these internally to create the high level API. But you can use these commands directly if you want something specific.

Values

pub fn call_function(
  driver: webdriver.WebDriver(state),
  params: call_function.CallFunctionParameters,
) -> Result(
  evaluate_result.EvaluateResult,
  @internal ButterbeeError,
)

Calls a function on the page with the given arguments.

Example

let function_params =
  call_function.new(target)
  |> call_function.with_function(function)
  |> call_function.with_arguments(arguments)

w3c

Search Document