butterbee/commands/session

Session commands

The session commands module contains commands found in the session section of the webdriver bidi protocol. Butterbee uses these internally to create the high level API. But you can use these commands directly if you want something specific.

Values

pub fn end(socket: @internal WebDriverSocket) -> Nil

Closes the current session.

w3c

pub fn new(
  request: request.Request(String),
  capabilities_request: capabilities_request.CapabilitiesRequest,
) -> Result(
  #(@internal WebDriverSocket, new.NewResult),
  @internal ButterbeeError,
)

Creates a new BiDi session with the given capabilities.

Example

let session = session.new(capabilities.default)

w3c

pub fn status(
  request: request.Request(String),
) -> Result(status.StatusResult, @internal ButterbeeError)

Returns information about whether a remote end is in a state in which it can create new sessions.

w3c

Search Document