butterbee/config/driver
The driver config module contains functions for parsing and creating driver configurations. The driver configuration specifies general options the webdriver needs to run, such as the maximum wait time, and the request timeout.
TOML Configuration Format
The driver configuration is defined under the
[tools.butterbee.driver] section of your gleam.toml file:
# gleam.toml
[tools.butterbee.driver]
max_wait_time = 20000
request_timeout = 5000
data_dir = "/tmp/butterbee"
Types
pub type DriverConfig {
DriverConfig(
max_wait_time: Int,
request_timeout: Int,
data_dir: String,
)
}
Constructors
-
DriverConfig( max_wait_time: Int, request_timeout: Int, data_dir: String, )
Values
pub const default: DriverConfig
pub const default_data_dir: String
Butterbee will use this data directory unless overridden. The data directory is used to store profile data for browsers.
pub const default_max_wait_time: Int
Butterbee will use this maximum wait time unless overridden. This settings determines how long butterbee will perform a retry function for before timing out (and failing the test).
pub const default_request_timeout: Int
Butterbee will use this request timeout unless overridden. Warn: This value is not currently used.