butterbee/driver

The driver module contains functions for interacting with the webdriver client

Values

pub fn close(
  driver: webdriver.WebDriver(state),
) -> Result(state, @internal ButterbeeError)

Closes the webdriver session, closes the browser, and returns the state of the webdriver

pub fn goto(
  driver: webdriver.WebDriver(state),
  url: String,
) -> webdriver.WebDriver(navigate.NavigateResult)

Navigates to the given url

pub fn new(
  browser: browser.BrowserType,
) -> webdriver.WebDriver(info.Info)

Start a new webdriver session connect to the browser session, using the configuration in the gleam.toml file. WebDriver holds the browsing context info in its state

pub fn new_with_config(
  browser_type: browser.BrowserType,
  config: config.ButterbeeConfig,
) -> webdriver.WebDriver(info.Info)

Start a new webdriver session connect to the browser session, using the ButterbeeConfig type

pub fn url(
  driver: webdriver.WebDriver(state),
) -> webdriver.WebDriver(String)

Returns the url of the current page

pub fn value(
  driver: webdriver.WebDriver(state),
) -> Result(state, @internal ButterbeeError)

Returns the state of the test without closing the webdriver session

pub fn wait(state: state, duration: Int) -> state

Pause for a given amount of time (in milliseconds) before continuing

Search Document