butterbee/commands/browser
Browser commands
The browser commands module contains commands found in the browser section of the webdriver bidi protocol. Butterbee usese these internally to create the high level API. But you can use these commands directly if you want something specific.
Values
pub fn close(
driver: webdriver.WebDriver(state),
) -> Result(definition.CommandResponse, @internal ButterbeeError)
Closes the current browser.